summaryrefslogtreecommitdiff
path: root/usr/src/uts/common/inet/ip/ip_if.c
diff options
context:
space:
mode:
Diffstat (limited to 'usr/src/uts/common/inet/ip/ip_if.c')
-rw-r--r--usr/src/uts/common/inet/ip/ip_if.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/usr/src/uts/common/inet/ip/ip_if.c b/usr/src/uts/common/inet/ip/ip_if.c
index 1bffa34682..1fbf9a5257 100644
--- a/usr/src/uts/common/inet/ip/ip_if.c
+++ b/usr/src/uts/common/inet/ip/ip_if.c
@@ -2813,8 +2813,8 @@ ill_capability_poll_capable(ill_t *ill, dl_capab_poll_t *ipoll,
/* Copy locally to get the members aligned */
bcopy((void *)ipoll, (void *)&poll, sizeof (dl_capab_poll_t));
- /* Get the tx function and handle from the driver */
- ill_poll->ill_tx = (ip_mac_tx_t)poll.poll_tx;
+ /* Get the tx function and handle from dld */
+ ill_poll->ill_tx = (ip_dld_tx_t)poll.poll_tx;
ill_poll->ill_tx_handle = (void *)poll.poll_tx_handle;
size = sizeof (dl_capability_req_t) + sizeof (dl_capability_sub_t) +